@@ -1,12 +1,12 @@
 #' @title coef.gic.DMR
 #'
-#' @description Extracts coefficients from a gic.DMR object (for the model with minimal gic).
+#' @description Extracts coefficients from a \code{gic.DMR} object (for the model with minimal gic).
 #'
-#' @param object Fitted gic.DMR object.
+#' @param object Fitted \code{gic.DMR} object.
 #'
 #' @param ... Further arguments passed to or from other methods.
 #'
-#' @details Similar to other coef methods, this function extracts coefficients from a fitted gic.DMR object for the model with minimal gic.
+#' @details Similar to other \code{coef} methods, this function extracts coefficients from a fitted \code{gic.DMR} object for the model with minimal gic.
 #'
 #' @return Vector of coefficients.
 #'
@@ -20,5 +20,5 @@
 #' @export
 coef.gic.DMR <- function(object, ...){
         out <- coef.DMR(object$dmr.fit, df = object$df.min)
-        return(out)
+        return(out[out!=0])
 }
